==> wikindx3_2_2.tar.gz: wikindx3/languages/en/ERRORS.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

TheWIKINDX Team 2004
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* ERRORS_en class (English)
* NOTE TO TRANSLATORS:  1/  '###' appearing anywhere in an array value will be replaced by text supplied by the core WIKINDX code.
*				Do not remove it and do not put space around it.
*			2/  Do not change the key (the first part) of an array element.
*			3/  Ensure that each array element value is enclosed in double quotes "..." and is followed by a comma "...",
*			4/  Both the class name and the constructor name should be changed to match the (case-sensitive) name of 
*				the folder your language files are in.  For example, if you are supplying a Klingon translation and 
*				your languages/ folder is languages/kn/, the class and constructor name for the file SUCCESS.php 
*				must both be SUCCESS_kn.
*
*****/
class ERRORS_en
{
// Constructor
	function ERRORS_en()
	{
	}
// English errors
	function loadArrays()
	{
		return array(
// General database errors
			"dbError" => array(
				"open"		=>	"Unable to open database.###",
				"write"		=>	"Unable to write to database.",
				"read"		=>	"Unable to read database.",
				"config"	=>	"Missing Configuration Parameter in config.php.",
				"populateTables"	=>	"Unable to populate database with tables.",
				"fileOpen"	=>	"Unable to open update/createMySQL.txt.",
				"updateMySQL"	=>	"Unable to update database with update/updateMySQL.txt.",
				"dbSpecified"	=>	"No RDBMS type selected in config.php.",
			),
			"sessionError" => array(
				"write"		=>	"Unable to write to session.",
			),
// General user input errors
			"inputError" => array(
				"nan"		=>	"Input is not a number.###",
				"missing"	=>	"Missing input.###",
				"invalid"	=>	"Invalid input.###",
				"userExists"	=>	"That username already exists",
				"mail"		=>	"Unable to email you - please contact the WIKINDX administrator",
// User registration - the hashKey supplied by email to a user has been deleted from the database as they did not 
// confirm their registration within 10 days.
				"noHashKey"	=>	"That key no longer exists. Please re-register",
				"styleExists"	=>	"That style already exists",
			),
// File operations (import/export)
			"file"	=> array(
				'write'			=>	"Unable to write to file###",
				'noSql'			=>	"You must first list or select resources",
				"read"			=>	"Unable to read directory or file###",
				"empty"			=>	"You have not yet exported any files",
				"upload"		=>	"File upload error",
				"folder"		=>	"Unable to create directory",
//				"bibtexMap"		=>	"You may not map more than one BibTeX field to the same 
//								WIKINDX field",
			),
// Following input, editing operations etc., these messages are printed when a user attempts to redo the operation (usually 
// by clicking on browser's 'reload' button)
			"done" => array(
				"resource" =>	"You have already created/edited/deleted that resource",
				"note" =>	"You have already created/edited/deleted that note",
				"quote" =>	"You have already created/edited/deleted that quote",
				"paraphrase" =>	"You have already created/edited/deleted that paraphrase",
				"musing" =>	"You have already created/edited/deleted that musing",
				"abstract" =>	"You have already created/edited/deleted that abstract",
				"creator" =>	"You have already created/edited/deleted that creator",
				"publisher" =>	"You have already created/edited/deleted that publisher",
				"collection" =>	"You have already created/edited/deleted that collection",
				"fileImport" =>	"You have already imported that file",
				"keyword"	=>	"You have already edited that keyword",
				"register"	=>	"You have already registered",
				"bibliography" =>	"You have already created/edited/deleted that bibliography",
				"custom" =>	"You have already edited/deleted that custom field",
				"attachAdd"	=>	"You have already attached that file",
				"attachDelete"	=>	"You have already deleted those files",
				"wp"	=>	"You have already deleted that paper",
			),
			"warning" => array(
// When inputting a new resource
				"resourceExists" => "At least one resource of that type with that title already exists",
// WIKINDX not in multi user mode - this is displayed at the logon screen
				"superadminOnly" => "Multi user has not been enabled - only the superadmin may log on",
// When editing a creator, the new one may be the same as an existing one.
				"creatorExists"	=>	"A creator of that name already exists in the database",
// When editing a publisher, the new one may be the same as an existing one.
				"publisherExists"	=>	"A publisher of that name and location already exists in the database",
// When editing a collection, the new one may be the same as an existing one.
				"collectionExists"	=>	"A collection of that name already exists in the database",
// When editing a keyword, the new one may be the same as an existing one.
				"keywordExists"	=>	"A keyword of that name already exists in the database",
// When importing a paper into the word processor
				"paperExists"	=>	"That paper already exists",
// When WIKINDX detects what is probably an incompatible browser for the SUWP, issue this warning.
				"suwpBrowserWarning"	=>	"Your browser probably will probably not work with the SUWP as 
it doesn't appear to have HTML design mode.  The WIKINDX SUWP is known to work with Mozilla, Firefox, Netscape 8 and Internet Explorer 6",
			),
		);
	}
}
?>

==> wikindx3_3_1.tar.gz: wikindx3/languages/en/ERRORS.php <==
<?php
/**********************************************************************************
WIKINDX: Bibliographic Management system.
Copyright (C)

This program is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program;
if not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

TheWIKINDX Team 2006
sirfragalot@users.sourceforge.net
**********************************************************************************/
/*****
* ERRORS_en class (English)
* NOTE TO TRANSLATORS:  1/  '###' appearing anywhere in an array value will be replaced by text supplied by the core WIKINDX code.
*				Do not remove it and do not put space around it.
*			2/  Do not change the key (the first part) of an array element.
*			3/  Ensure that each array element value is enclosed in double quotes "..." and is followed by a comma "...",
*			4/  Both the class name and the constructor name should be changed to match the (case-sensitive) name of 
*				the folder your language files are in.  For example, if you are supplying a Klingon translation and 
*				your languages/ folder is languages/kn/, the class and constructor name for the file SUCCESS.php 
*				must both be SUCCESS_kn.
*
*****/
class ERRORS_en
{
// Constructor
	function ERRORS_en()
	{
	}
// English errors
	function loadArrays()
	{
		return array(
// General database errors
			"dbError" => array(
				"open"		=>	"Unable to open database.###",
				"write"		=>	"Unable to write to database.",
				"read"		=>	"Unable to read database.",
				"config"	=>	"Missing Configuration Parameter in config.php.",
				"populateTables"	=>	"Unable to populate database with tables.",
				"fileOpen"	=>	"Unable to open update/createMySQL.txt.",
				"updateMySQL"	=>	"Unable to update database with update/updateMySQL.txt.",
				"dbSpecified"	=>	"No RDBMS type selected in config.php.",
			),
			"sessionError" => array(
				"write"		=>	"Unable to write to session.",
			),
// General user input errors
			"inputError" => array(
				"nan"		=>	"Input is not a number.###",
				"missing"	=>	"Missing input.###",
				"invalid"	=>	"Invalid input.###",
				"userExists"	=>	"That username already exists",
				"mail"		=>	"Unable to email you - please contact the WIKINDX administrator",
// User registration - the hashKey supplied by email to a user has been deleted from the database as they did not 
// confirm their registration within 10 days.
				"noHashKey"	=>	"That key no longer exists. Please re-register",
				"styleExists"	=>	"That style already exists",
// When exporting bibliographies to bibtex or endnote and custom fields are mapped, duplicate field names are not allowed.
				"duplicateCustomMap" => "Duplicate export field names",
			),
// File operations (import/export)
			"file"	=> array(
				'write'			=>	"Unable to write to file###",
				'noSql'			=>	"You must first list or select resources",
				"read"			=>	"Unable to read directory or file###",
				"empty"			=>	"You have not yet exported any files",
				"upload"		=>	"File upload error",
				"folder"		=>	"Unable to create directory",
				"fieldMap"		=>	"You may not map more than one unknown field to the same WIKINDX field",
// Don't translate 'post_max_size' and 'upload_max_filesize'
				"fileSize"		=>	"Attachment exceeds maximum post_max_size or upload_max_filesize in php.ini (> ### bytes)",
// This is not really an error but a prompt in the word processor indicating that the file has not been saved yet.
				"suwpNotSaved"	=>	"Paper not yet saved",
			),
// Following input, editing operations etc., these messages are printed when a user attempts to redo the operation (usually 
// by clicking on browser's 'reload' button)
			"done" => array(
				"resource" =>	"You have already created/edited/deleted that resource",
				"note" =>	"You have already created/edited/deleted that note",
				"quote" =>	"You have already created/edited/deleted that quote",
				"paraphrase" =>	"You have already created/edited/deleted that paraphrase",
				"musing" =>	"You have already created/edited/deleted that musing",
				"abstract" =>	"You have already created/edited/deleted that abstract",
				"creator" =>	"You have already created/edited/deleted that creator",
				"publisher" =>	"You have already created/edited/deleted that publisher",
				"collection" =>	"You have already created/edited/deleted that collection",
				"fileImport" =>	"You have already imported that file",
				"keyword"	=>	"You have already edited that keyword",
				"register"	=>	"You have already registered",
				"bibliography" =>	"You have already created/edited/deleted that bibliography",
				"custom" =>	"You have already edited/deleted that custom field",
				"attachAdd"	=>	"You have already attached that file",
				"attachDelete"	=>	"You have already deleted those files",
				"wp"	=>	"You have already deleted that paper",
			),
			"warning" => array(
// When inputting a new resource
				"resourceExists" => "At least one resource of that type with that title already exists",
// WIKINDX not in multi user mode - this is displayed at the logon screen
				"superadminOnly" => "Multi user has not been enabled - only the superadmin may log on",
// When editing a creator, the new one may be the same as an existing one.
				"creatorExists"	=>	"A creator of that name already exists in the database",
// When editing a publisher, the new one may be the same as an existing one.
				"publisherExists"	=>	"A publisher of that name and location already exists in the database",
// When editing a collection, the new one may be the same as an existing one.
				"collectionExists"	=>	"A collection of that name already exists in the database",
// When editing a keyword, the new one may be the same as an existing one.
				"keywordExists"	=>	"A keyword of that name already exists in the database",
// When importing a paper into the word processor
				"paperExists"	=>	"That paper already exists",
// When WIKINDX detects what is probably an incompatible browser for the SUWP, issue this warning.
				"suwpBrowserWarning"	=>	"Your browser probably will probably not work with the SUWP as 
it doesn't appear to have HTML design mode.  The WIKINDX SUWP is known to work with Mozilla, Firefox, Netscape 8 and Internet Explorer 6",
			),
		);
	}
}
?>
